@@ -2,10 +2,13 @@ from shutil import which
 import subprocess
 
 
-def prompt(choices=None, header=""):
+def prompt(choices=None, header="", multi=False):
     fzf_options = [] 
     if header:
         fzf_options += [f"--header={header}", ]
+    if multi:
+        fzf_options += [f"--multi", ]
+
 
     fzf = FzfPrompt()
     return fzf.prompt(choices, fzf_options=fzf_options)
